<?php

namespace Drupal\link_allowed_hosts\Plugin\Validation\Constraint;

use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;

/**
 * Validate the LinkAllowedHost constraint.
 */
class LinkAllowedHostConstraintValidator extends ConstraintValidator {

  /**
   * The hosts option.
   *
   * @var string
   */
  public $hosts;

  /**
   * {@inheritdoc}
   */
  public function validate($items, Constraint $constraint) {
    if ($items->isEmpty()) {
      return NULL;
    }

    $allowed_hosts = $constraint->getHosts();
    /** @var \Drupal\link\Plugin\Field\FieldType\LinkItem $item */
    foreach ($items as $delta => $item) {
      $uri = $item->uri;

      // If no scheme set (in case of internal:, entity: etc.), exit early
      // and let Drupal handle.
      if (!filter_var($uri, FILTER_VALIDATE_URL)) {
        continue;
      }
      elseif ($item->isExternal()) {
        $url = parse_url($uri);
        if (!isset($allowed_hosts[$url['host']])) {
          $this->context->buildViolation($constraint->message)
            ->setParameter('%host', $url['host'])
            ->setParameter('%allowed_hosts', implode(', ', $allowed_hosts))
            ->atPath($delta)
            ->addViolation();
        }
      }
    }
  }

}
